Opening WWT in Python
=====================

There are several ways to open up the WorldWide Telescope viewer in Python,
depending on the environment that you're working in.

.. toctree::
   :maxdepth: 2

   jupyterlab
   jupyter
   qt
   windows
